@@ -159,3 +159,11 @@ class data_manager(object):
         result = sql.query(sql_query, show_sql)
         sql.become_free()
         return result
+
+    def truncate(self, table, show_sql=False):
+        sql = self.find_free_sql()
+        # sql.become_busy()
+        # print('执行这次sql请求的链接是', id(sql))
+        result = sql.truncate(table, show_sql)
+        sql.become_free()
+        return result
