@@ -1,3 +1,6 @@
+from pprint import pprint
+
+from .construct_file import frame_constructor
 from .dbserver.data_manager import data_manager
 db_config = None
 
@@ -35,6 +38,8 @@ class Data(object):
     def check_connections(base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+        if base_id not in Data.Base_pool:
+            return
         sql_pool = Data.Base_pool[base_id].sql_pool
         busy_list = []
         all_list = []
@@ -71,18 +76,21 @@ class Data(object):
     def add_new_sql(base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         return Data.Base_pool[base_id].new() if base_id in Data.Base_pool else None
 
     @staticmethod
     def create(table, colums, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         return Data.Base_pool[base_id].create(table, colums, show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
     def insert(table, params, is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         data = Data.Base_pool[base_id].insert(table, params, is_commit, show_sql) if base_id in Data.Base_pool else None
         return data
 
@@ -90,18 +98,21 @@ class Data(object):
     def find(table, conditions, or_cond=None, fields=('*',), order=None, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         return Data.Base_pool[base_id].find(table, conditions, or_cond, fields, order, show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
     def select(table, conditions, or_cond=None, fields=('*',), group=None, order=None, limit=None, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         return Data.Base_pool[base_id].select(table, conditions, or_cond, fields, group, order, limit, show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
     def update(table, conditions, or_cond=None, params=None, is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         Data.Base_pool[base_id].update(table, conditions, params, or_cond, is_commit, show_sql) if base_id in Data.Base_pool else None
         return
 
@@ -109,6 +120,7 @@ class Data(object):
     def delete(table, conditions, or_cond=None, is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         data = Data.Base_pool[base_id].delete(table, conditions, or_cond, is_commit, show_sql) if base_id in Data.Base_pool else None
         return data
 
@@ -116,18 +128,49 @@ class Data(object):
     def find_last(table, conditions, info, limit, fields="*", show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+
         return Data.Base_pool[base_id].find_last(table, conditions, info, limit, fields, show_sql) if base_id in Data.Base_pool else None
 
+    @staticmethod
+    def truncate(table, show_sql=False, base_id='default', show_manager_id=False):
+        if show_manager_id is True:
+            print('本次任务通过', base_id, '执行')
+        return Data.Base_pool[base_id].truncate(table, show_sql) if base_id in Data.Base_pool else None
+
+
     @staticmethod
     def query(sql, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
+        if base_id not in Data.Base_pool:
+            return
         return Data.Base_pool[base_id].query(sql, show_sql) if base_id in Data.Base_pool else None
 
+    @staticmethod
+    def map_all_db(base_id='default',show_manager_id=False,file_path='',file_name='fb_frame.py'):
+        if show_manager_id is True:
+            print('本次任务通过', base_id, '执行')
+        if base_id not in Data.Base_pool:
+            print('base id not exist.. construct fail')
+            return
+        all_table = Data.query('show tables',base_id=base_id)
+        table_index = {}
+        for i in all_table:
+            table_name = i[0]
+            res = Data.query('desc '+str(table_name),base_id=base_id)
+            table_index[table_name] = list(res)
+
+        base_manager = Data.Base_pool[base_id]
+        db_name = base_manager.t_data['database']
+        constructor = frame_constructor(db_name,table_index,file_path,file_name)
+        constructor.dump()
+        return table_index
+
+
+
+
+
+
+
+
 
-if __name__ == '__main__':
-    res = Data.select('withdraw_record', [('user_id', 'in', tuple(range(1, 10)))], group=['user_id'],
-                      fields=['user_id', 'sum(share)'], show_sql=False)
-    for i in res:
-        print(i)
-        print(i['sum(share)'])
